@@ -1,4 +1,4 @@
-// Copyright 2018-2025 the Deno authors. MIT license.
+// Copyright 2018-2026 the Deno authors. MIT license.
 
 use std::borrow::Cow;
 use std::cell::RefCell;
@@ -1126,6 +1126,14 @@ async fn run_tests_for_worker_inner(
       continue;
     }
 
+    // Close idle Node.js HTTP Agent connections to prevent cross-test
+    // pollution and false positive resource leak detection from pooled
+    // keepAlive connections.
+    _ = worker.js_runtime.execute_script(
+      located_script_name!(),
+      "Deno[Deno.internal].node?.closeIdleConnections?.()",
+    );
+
     // Await activity stabilization
     if let Some(diff) = sanitizers::wait_for_activity_to_stabilize(
       worker,
